import { EventEmitter } from '@angular/core';
import { CopyService } from './copy-service/copy.service';
/**
 * A config containing properties for copy components
 */
export declare abstract class CopyBase {
    protected copyService: CopyService;
    protected _copyDefaults: {
        copyBtnTooltipText: string;
        tooltipCopiedText: string;
    };
    /**
     * Copy button aria label (announced to screen readers)
     */
    buttonAriaLabel: string;
    /**
     * A tooltip that describes the value to be copied
     */
    tooltipText: string;
    /**
     * Placement for the tooltip
     */
    tooltipPlacement: string;
    /**
     * A tooltip that describes what the copy button does
     */
    copyBtnTooltipText: string;
    /**
     * A tooltip that informs user that copy action recently occurred
     */
    tooltipCopiedText: string;
    /**
     * Placement for the copy button tooltip
     */
    copyBtnTooltipPlacement: string;
    /**
     * The value to be copied to the clipboard
     */
    value: string;
    /**
     * A width to set on the copy container
     */
    width: string;
    /**
     * Event emitted when values are copied to the clipboard
     */
    onCopy: EventEmitter<{}>;
    private _recentlyCopied;
    /**
     * Default constructor
     */
    constructor(copyService: CopyService);
    /**
     * Returns the flag indicating copy action has just happened
     *
     * @returns {boolean} True if copy action has been triggered
     */
    readonly recentlyCopied: boolean;
    /**
     * Copy given value to the clipboard
     */
    copy(): void;
}
